Два нових ключових слова, що називаються `let` і` const`, дозволяють оголошувати змінні в області видимості блоків. Традиційні змінні, оголош `var`, завжди були визначені для всієї функції. Обмеження видимості блоків означає, що `let`/` const` визначені для використання У фігурних дужках `{...}`.

Змінні, визначені за допомогою `let`, можуть змінювати значеня, але` const` не дозволяє перепризначення. `const` нагадує ключове слово` final` Java.

```javascript
// block.js
{
  var a = 10;
  let b = 20;
  const tmp = a;
  a = b;
  b = tmp;
  // tmp = 30; Невдача. Призведе до помилки SyntaxError
}

// a = 20、 змінну `a` оголошено за допомогою `var`, тому вона доступна поза межами блоку
console.log(a);
// змінні, визначені за допомогою `let`, недоступні. Це призведе до: ReferenceError b is not defined
console.log(b);
// Те саме стосується `const`: tmp is not defined
console.log(tmp);
```

Використання `let` та ` const` є бажаним, оскільки воно ускладнює просочування змінних назовні області видимості блоку.

# Вправа

Змінити наступний файл, обравши між `var`, `let` або `const`, так щоб код поводився, відповідно до опису в коментарях

```javascript
'use strict';
// Ця змінна `a` має бути доступною поза межами блоку.
var|let|const a = 5;

// Ця змінна `b` не повинна бути перепризначена.
var|let|const b = process.argv[2];

if (a === 5) {
  // Ця змінна `c` повинна бути доступною лише у цьому блоці.
  var|let|const c = 4;
  console.log(c);  // 4

  // Ця змінна `b` має бути доступною лише у цьому блоці, і вона не повинна бути перепризначена.
  var|let|const b = 8;
  console.log(b); // 8
}

console.log(a); // 5
console.log(b);
try {
  // Спроба змінити значення `c`
  c = 1000;
} catch (e) {
  // але має відбутися помилка `c is not defined`.
  console.log(e);
}
```
